Class: Array
- Inherits:
-
Object
- Object
- Array
- Defined in:
- lib/array_extensions.rb
Overview
Motiro - A project tracking tool Copyright (C) 2006-2008 Thiago Arrais
This program is free software; you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation; either version 3 of the License, or any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
You should have received a copy of the GNU Affero General Public License along with this program. If not, see http://www.gnu.org/licenses/.
Instance Method Summary collapse
Instance Method Details
#xml_join ⇒ Object
19 20 21 22 23 24 25 26 27 |
# File 'lib/array_extensions.rb', line 19 def xml_join str = '' each do |s| str << ' ' unless str.empty? || s.empty? || str.match(/<[^\/][^>]*>\Z/) || s.match(/\A<\//) str << s end str end |