Class: Hash
- Inherits:
-
Object
- Object
- Hash
- Defined in:
- lib/stub_hash.rb
Overview
Motiro - A project tracking tool Copyright (C) 2006-2008 Thiago Arrais
This program is free software; you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation; either version 3 of the License, or any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
You should have received a copy of the GNU Affero General Public License along with this program. If not, see http://www.gnu.org/licenses/.
Instance Method Summary collapse
Dynamic Method Handling
This class handles dynamic methods through the method_missing method
#method_missing(name, *args) ⇒ Object
18 19 20 |
# File 'lib/stub_hash.rb', line 18 def method_missing(name, *args) self[name] end |