Class: Revision
- Inherits:
-
ActiveRecord::Base
- Object
- ActiveRecord::Base
- Revision
- Defined in:
- app/models/revision.rb
Overview
Motiro - A project tracking tool Copyright (C) 2006-2008 Thiago Arrais
This program is free software; you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation; either version 3 of the License, or any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
You should have received a copy of the GNU Affero General Public License along with this program. If not, see http://www.gnu.org/licenses/.
Instance Method Summary collapse
Instance Method Details
#diff(other) ⇒ Object
28 29 30 31 |
# File 'app/models/revision.rb', line 28 def diff(other) ChunkDiffer.new.diff(text.split($/), other.text.split($/)) end |
#editable_by?(user) ⇒ Boolean
26 |
# File 'app/models/revision.rb', line 26 def editable_by?(user) page.editable_by?(user) end |